<?php
/*
  Plugin Name: BlueskyTimeline for Wordpress
  Plugin URI: https://www.heion.net/knowledge/blueskytimeline-for-wordpress_20240229/
  Description: Blueskyの埋め込みタイムラインウィジェット
  Version: 0.2.2
  Author: SWD
  Author URI: https://www.heion.net/
  License: GPLv2
  Text Domain: bluesky-timeline
  Domain Path: /languages
 */

if(!defined('ABSPATH')) {exit;}

 add_action('init', 'BlueskyTimeline::init');

 class BlueskyTimeline{
    const VERSION           = '0.2.2';
    const PLUGIN_ID         = 'bluesky-timeline';
    const DOMAIN            = 'bluesky-timeline';
    const CONFIG_MENU_SLUG  = self::PLUGIN_ID . '-config';
    const CREDENTIAL_ACTION = self::PLUGIN_ID . '-nonce-action';
    const CREDENTIAL_NAME   = self::PLUGIN_ID . '-nonce-key';
    const PLUGIN_DB_PREFIX  = self::PLUGIN_ID . '_';
    const COMPLETE_CONFIG   = self::PLUGIN_ID . '-complete';
    

    static function init(){
        return new self();
    }

    function __construct(){
        if (is_admin() && is_user_logged_in()){
            load_plugin_textdomain(self::DOMAIN, false, basename( dirname( __FILE__ ) ).'/languages');
            add_action('admin_menu', [$this, 'set_plugin_sub_menu']);
            add_action('admin_init', [$this, 'save_config']);
        }
    }

    function set_plugin_sub_menu(){

        add_submenu_page(
            'options-general.php',
            __('Bluesky Timeline',self::DOMAIN),
            __('Bluesky Timeline',self::DOMAIN),
            'manage_options',
            'bluesky-timeline',
            [$this, 'setup_form']);
    }

    function setup_form(){
        $handle = get_option(self::PLUGIN_DB_PREFIX . "handle");
        $pass = get_option(self::PLUGIN_DB_PREFIX . "pass");
        $theme = get_option(self::PLUGIN_DB_PREFIX . "theme");
        $gtm = get_option(self::PLUGIN_DB_PREFIX . "gtm");
    ?>
        <style>
            .setup_box{
                display: flex;
                flex-wrap: wrap;
                gap:20px;
                & label{
                    display: flex;
                }
                #bs_setup{
                    min-width:300px;
                    flex:1;
                }
                .bs_handle{
                    position: relative;
                    &:before{
                        content:"@";
                        display: block;
                        position: absolute;
                        left:10px;
                        top:-2px;
                        bottom:0;
                        margin:auto;
                    }
                    & input{
                        padding-left:22px;
                        width:260px;
                    }
                }
                .bs_pass{
                    & input{
                        width:260px;
                    }
                }
                .code_box{
                    border-radius: 6px;
                    padding:20px;
                    background-color: rgba(200,200,200,0.3);
                    flex:2;
                    .number{
                        width:5em;
                    }
                    .size_box{
                        margin-bottom: 10px;
                        display: flex;
                        gap:20px;
                    }
                    & iframe{
                        border-radius: 3px;
                        border:2px solid #333;
                        background:#444 url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="100" height="100" viewBox="0 0 24 24"><path fill="currentColor" d="M12 2A10 10 0 1 0 22 12A10 10 0 0 0 12 2Zm0 18a8 8 0 1 1 8-8A8 8 0 0 1 12 20Z" opacity=".5"/><path fill="currentColor" d="M20 12h2A10 10 0 0 0 12 2V4A8 8 0 0 1 20 12Z"><animateTransform attributeName="transform" dur="1s" from="0 12 12" repeatCount="indefinite" to="360 12 12" type="rotate"/></path></svg>');
                        background-position: 50% 50%;  
                        background-repeat: no-repeat;                      
                    }
                }
                #output_code{
                    width:100%;
                    border:2px solid #333;
                    padding:6px;
                    font-size:16px;
                }
            }
        </style>
        <div class="wrap">
        <h1>
            <svg fill="none" viewBox="0 0 64 57" width="48" style="width: 28px;vertical-align: middle;margin-right:5px;"><path fill="#0085ff" d="M13.873 3.805C21.21 9.332 29.103 20.537 32 26.55v15.882c0-.338-.13.044-.41.867-1.512 4.456-7.418 21.847-20.923 7.944-7.111-7.32-3.819-14.64 9.125-16.85-7.405 1.264-15.73-.825-18.014-9.015C1.12 23.022 0 8.51 0 6.55 0-3.268 8.579-.182 13.873 3.805ZM50.127 3.805C42.79 9.332 34.897 20.537 32 26.55v15.882c0-.338.13.044.41.867 1.512 4.456 7.418 21.847 20.923 7.944 7.111-7.32 3.819-14.64-9.125-16.85 7.405 1.264 15.73-.825 18.014-9.015C62.88 23.022 64 8.51 64 6.55c0-9.818-8.578-6.732-13.873-2.745Z"></path></svg>
            <?php _e('Bluesky Embedded Timeline',self::DOMAIN);/*Bluesky埋め込みタイムライン*/ ?>
        </h1>
<?php 
$transients = get_transient( self::COMPLETE_CONFIG );

if( !empty($transients) ){
  echo '<div id="settings_updated" class="updated notice is-dismissible"><p>'.$transients.'</p></div>';
}
?>

        <section class="setup_box">
            <form action="" method='post' id="bs_setup">
                <?php wp_nonce_field(self::CREDENTIAL_ACTION, self::CREDENTIAL_NAME) ?>
                <p>
                    <label for="bs_handle"><?php _e('Handle:',self::DOMAIN);/*ハンドル：*/ ?></label>
                    <span class="bs_handle"><input type="text" id="bs_handle" name="bs_handle" value="<?php echo $handle; ?>" placeholder="****.bsky.social" /></span>
                </p>
                <p>
                    <label for="bs_pass"><?php _e('Password:',self::DOMAIN);/*パスワード：*/ ?></label>
                    <span class="bs_pass"><input type="password" id="bs_pass" name="bs_pass" value="<?php echo $pass; ?>"/></span>
                </p>
                <hr>
                <strong><?php _e('Options',self::DOMAIN);/*オプション*/ ?></strong>
                <p>
                <label for="bs_theme"><?php _e('Theme Color:',self::DOMAIN);/*テーマカラー：*/ ?></label>
                <select name="bs_theme" id="bs_theme">
                    <option value=""<?php if($theme == ''){echo ' selected';} ?>><?php _e('Light (default)',self::DOMAIN);/*ライト（デフォルト）*/ ?></option>
                    <option value="gray"<?php if($theme == 'gray'){echo ' selected';} ?>><?php _e('Gray',self::DOMAIN);/*グレー*/ ?></option>
                    <option value="dark"<?php if($theme == 'dark'){echo ' selected';} ?>><?php _e('Dark',self::DOMAIN);/*ダーク*/ ?></option>
                </select>
                </p>
                <p>
                <label for="bs_gtm"><?php _e('GTM Container ID:',self::DOMAIN);/*GTMコンテナID：*/ ?></label>
                <span class="bs_gtm"><input type="text" id="bs_gtm" name="bs_gtm" value="<?php echo $gtm; ?>" placeholder="GTM-*****" /></span><br>
                <?php _e('*If you would like to place GA4 tags via Google Tag Manager to measure access and click events, etc., please enter the information.',self::DOMAIN);/*※Googleタグマネージャー経由でGA4タグを設置しアクセスやクリックイベント計測したい場合などはご入力ください。*/ ?>
                </p>
                <hr>

                <p><input type='submit' value='<?php _e('Save',self::DOMAIN);/*保存*/ ?>' class='button button-primary button-large'></p>

            </form>
            <?php if(!empty($handle) && !empty($pass)){ ?>
            <div class="code_box">
            
                <div class="size_box">
                    <div>
                    <label for="w_width"><?php _e('Width:',self::DOMAIN);/*横幅：*/ ?></label>
                    <input type="number" class="number" id="w_width" name="w_width" value="420" min="300" step="10" /> px
                    </div>
                    <div>
                    <label for="w_height"><?php _e('Height:',self::DOMAIN);/*高さ：*/ ?></label>
                    <input type="number" class="number" id="w_height" name="w_height" value="500" min="300" step="10" /> px
                    </div>
                </div>
                <?php _e('*Width and height values are not saved.',self::DOMAIN);/*※横幅と高さの値は保存されません*/ ?>

                <hr>
                <h4><?php _e('Embedded code:',self::DOMAIN);/*埋め込みコード：*/ ?></h4>
                <p>
                    <input type="text" id="output_code" name="output_code" value="" readonly />
                </p>
                <p><button id="copy_btn" class='button button-primary button-large'><?php _e('Copy to clipboard',self::DOMAIN);/*クリップボードにコピーする*/ ?></button></p>
                <hr>
                <h4><?php _e('Preview:',self::DOMAIN);/*プレビュー：*/ ?></h4>
                <p>
                    <iframe src="<?php echo plugin_dir_url( __FILE__ ).'widget/'; ?>" width="420" height="500"></iframe>
                </p>
                <p><?php _e('*The width and height entered are not reflected on the preview.',self::DOMAIN);/*※プレビュー上では入力された横幅と高さは反映されません。*/ ?></p>
                <p><?php _e('*Although borders are included in the preview, actual iframe tags do not have borders, so please adjust the style sheet accordingly.',self::DOMAIN);/*※プレビュー上ではボーダー（枠線）を入れていますが、実際のiframeタグにはボーダーは入りませんので適宜スタイルシートで調整ください。*/ ?></p>
            </div>
            <?php } ?>
        </section>

      </div>

      
        <script>
            function htmlspecialchars(str){
                return (str + '').replace(/&/g,'&amp;')
                                .replace(/"/g,'&quot;')
                                .replace(/'/g,'&#039;')
                                .replace(/</g,'&lt;')
                                .replace(/>/g,'&gt;');
            }

            let w_width = document.getElementById("w_width");
            let w_height = document.getElementById("w_height");
            
            function code_put(){
                let iframe_code = '<iframe src="<?php echo plugin_dir_url( __FILE__ ).'widget/'; ?>" width="'+w_width.value+'" height="'+w_height.value+'" title="BlueskyTimeline"></iframe>';
                document.getElementById("output_code").value = iframe_code;
            }
            code_put();

            w_width.addEventListener('change', function(){
                code_put();
            });
            w_height.addEventListener('change', function(){
                code_put();
            });

            let btn = document.getElementById("copy_btn");
            btn.addEventListener('click', function(e) {
                copy_to_clipboard(document.getElementById("output_code").value);
            });
            
            function copy_to_clipboard(value) {
                if(navigator.clipboard) {
                    var copyText = value;
                    navigator.clipboard.writeText(copyText).then(function() {
                        alert('<?php _e('I copied the embed code to the clipboard.',self::DOMAIN);/*クリップボードに埋め込みコードをコピーしました。*/ ?>');
                    });
                } else {
                    alert('<?php _e('Copy to clipboard is not supported.',self::DOMAIN);/*クリップボードへのコピーに対応していません。*/ ?>');
                }
            }

        </script>

<?php
    }

    /** 設定画面の項目をデータベースに保存する */
    function save_config(){

        if (isset($_POST[self::CREDENTIAL_NAME]) && $_POST[self::CREDENTIAL_NAME]) {
            if (check_admin_referer(self::CREDENTIAL_ACTION, self::CREDENTIAL_NAME)) {

                // 保存処理
                $handle = htmlspecialchars($_POST['bs_handle']);
                update_option(self::PLUGIN_DB_PREFIX . 'handle', $handle);
                $pass = htmlspecialchars($_POST['bs_pass']);
                update_option(self::PLUGIN_DB_PREFIX . 'pass', $pass);
                $theme = htmlspecialchars($_POST['bs_theme']);
                update_option(self::PLUGIN_DB_PREFIX . 'theme', $theme);
                $gtm = htmlspecialchars($_POST['bs_gtm']);
                update_option(self::PLUGIN_DB_PREFIX . 'gtm', $gtm);

                $completed_text = __('The settings have been saved. Please check that the timeline is displayed correctly in the preview area.',self::DOMAIN);//"設定の保存が完了しました。プレビューエリアに正しくタイムラインが表示されているかご確認ください。";

                set_transient(self::COMPLETE_CONFIG, $completed_text, 5);

                wp_safe_redirect(menu_page_url(self::CONFIG_MENU_SLUG), false);

            }
        }
    }

}

//アップデートチェック
require 'updater/plugin-update-checker.php';
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

$myUpdateChecker = PucFactory::buildUpdateChecker(
	'https://www.heion.net/plugins-update/bluesky-timeline.json',
	__FILE__,
	'bluesky-timeline'
);

/** アンインストール処理 **/
register_uninstall_hook(__FILE__, 'bs_uninstall' );
/** アンインストール処理 **/
function bs_uninstall(){
    delete_option('bluesky-timeline_handle');
    delete_option('bluesky-timeline_pass');
    delete_option('bluesky-timeline_theme');
    delete_option('bluesky-timeline_gtm');
}

?>