<?php
require(dirname(__FILE__,5)."/wp-load.php");

include_once(ABSPATH . 'wp-admin/includes/plugin.php');
$VERSION  = "v.0.2.2";
if (is_plugin_active('bluesky-timeline/bluesky-timeline.php')) {

    $DOMAIN = 'bluesky-timeline';
    load_plugin_textdomain('bluesky-timeline', false, dirname( plugin_basename( __FILE__ ),2 ).'/languages');

    function get_bs_token($handle, $password){

        $ch = curl_init("https://bsky.social/xrpc/com.atproto.server.createSession");
        curl_setopt_array($ch, [
            CURLOPT_CONNECTTIMEOUT => 10,
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_POST => true,
            CURLOPT_HTTPHEADER => [
                "Content-Type: application/json",
            ],
            CURLOPT_POSTFIELDS => json_encode([
                "identifier" => $handle,
                "password" => $password,
            ]),
        ]);
        $response = curl_exec($ch);
        curl_close($ch);
        $responseJson = json_decode($response, true);

        return $responseJson["accessJwt"];
    }

    function timeline($handle, $jwt){

        $curl = curl_init();
        curl_setopt_array($curl, array(
        CURLOPT_URL => 'https://bsky.social/xrpc/app.bsky.feed.getAuthorFeed?actor='.$handle.'&filter=posts_no_replies',
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_ENCODING => '',
        CURLOPT_MAXREDIRS => 10,
        CURLOPT_TIMEOUT => 0,
        CURLOPT_FOLLOWLOCATION => true,
        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
        CURLOPT_CUSTOMREQUEST => 'GET',
        CURLOPT_HTTPHEADER => array(
            "Accept: application/json",
            "Authorization: Bearer {$jwt}"
            ),
        ));

        $response = curl_exec($curl);
        curl_close($curl);
        $responseJson = json_decode($response, true);

        return $responseJson;
    }

    //タイムラインHTMLキャッシュ
    $cache = get_transient('timeline-cache');
    //管理画面アップデートフラグ
    $update_flg = get_transient('bluesky-timeline-complete');
    //キャッシュローテーションフラグ
    $rotation_flg = get_transient('cache-rotation');
    //差分チェック
    $integrity = get_transient('integrity-time');
    
    //キャッシュローテーション時間内で管理画面からのアップデートでない場合
    if( !empty($cache) && !empty($rotation_flg) && empty($update_flg) ){
        // キャッシュから出力
        echo $cache;
    }else{

        //HTMLキャッシュが存在していて管理画面からのアップデートでない場合
        if( !empty($cache) && empty($update_flg) ){
            // キャッシュから出力
            echo $cache;
        }

        //10分間のキャッシュを再度セット
        set_transient( 'cache-rotation', 1, MINUTE_IN_SECONDS * 10 );

        $handle = htmlspecialchars(get_option('bluesky-timeline_handle'));
        $password = htmlspecialchars(get_option('bluesky-timeline_pass'));
        $gtm = htmlspecialchars(get_option('bluesky-timeline_gtm'));
        // JWT取得
        $jwt = get_bs_token($handle, $password);
        // タイムラインリクエスト
        $response = timeline($handle, $jwt);
        //print_r($response);

        // JSONレスポンスチェック
        if(!isset($response['feed'])){
            echo "JSON取得エラー（ハンドル,パスワードが間違っている可能性があります）";
            exit;
        }

        // 差分がなく、管理画面からの更新でもないときは終了
        if($response['feed'][0]['post']['record']['createdAt'] == $integrity && empty($update_flg)){
            exit;
        }

        if(htmlspecialchars(get_option('bluesky-timeline_theme')) == "gray"){
            $color = "255,255,255";
            $background = "#161e27";
        }elseif(htmlspecialchars(get_option('bluesky-timeline_theme')) == "dark"){
            $color = "255,255,255";
            $background = "#000";
        }else{
            $color = "60,60,60";
            $background = "#FFF";
        }

        function makeHtml($background, $color, $response, $gtm, $DOMAIN, $VERSION){
            ob_start();
?><!DOCTYPE html>
<html lang="<?php _e('en',$DOMAIN);/*ja*/ ?>">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="robots" content="noindex,nofollow">
<?php
    if(!empty($gtm)){
?>
    <!-- Google Tag Manager -->
    <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
    new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
    j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
    'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
    })(window,document,'script','dataLayer','<?php echo $gtm; ?>');</script>
    <!-- End Google Tag Manager -->
<?php
    }
?>
    <title>BlueskyTimeline</title>
<style>
    :root{
        --bs_timeline_box_width:500px;
        --bs_timeline_box_height:580px;
        --bs_timeline_box_background:<?php echo $background; ?>;
        --bs_timeline_box_bghover:120,120,120;
        --bs_timeline_box_color:<?php echo $color; ?>;
        --bs_timeline_box_font-size:15px;
    }
    html,body{
        margin:0;
        padding:0;
        box-sizing: initial;
        background: var(--bs_timeline_box_background);
        font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif;
    }
    #bs_timeline_box{
        background: var(--bs_timeline_box_background);
        color: rgba(var(--bs_timeline_box_color),1);
        font-size: var(--bs_timeline_box_font-size);
        max-width: 100%;        
        display: flex;
        flex-wrap: wrap;
        gap: 1px;
        line-height: 145%;
        container: layout/inline-size;
        margin-block-start: 0px;
        margin-block-end: 0px;
        & section{
            padding: 10px 10px 12px;
            width:calc(100% - 20px);
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            cursor: pointer;
            transition: background 0.15s ease-out;
            &:hover{
                background: rgba(var(--bs_timeline_box_bghover),0.18);
            }
            .bs_timeline_author_repost{
                font-size:clac(var(--bs_timeline_box_font-size) - 2px);
                font-weight:bold;
                width:100%;
                padding-left: 50px;
                text-indent: -25px;
                color:rgba(var(--bs_timeline_box_color),0.7);
                & a{
                    text-decoration: none;
                    color:rgba(var(--bs_timeline_box_color),0.7);
                    &:hover{
                        text-decoration: underline;
                    }
                }
                & svg{
                    vertical-align: middle;
                }
            }
            .bs_timeline_icon{
                width: 40px;
                height: 40px;
                border-radius: 50%;
                background: #FFF;
                & a{
                    display: block;
                    position: relative;
                    overflow: hidden;
                    &::before{
                        content:"";
                        width:40px;
                        height:40px;
                        border-radius: 50%;
                        background:rgba(var(--bs_timeline_box_bghover),0);
                        transition: all 0.25s ease-out;
                        position: absolute;
                        mix-blend-mode: multiply;
                    }
                    &:hover{
                        &::before{
                            background:rgba(var(--bs_timeline_box_bghover),0.5);
                        }
                    }
                }
                & img{
                    border-radius: 50%;
                    width: 100%;
                    height: 100%;
                }
             }
             .bs_timeline_contents{
                width:calc(100% - 50px);
             }
             .bs_timeline_title{
                display: flex;
                justify-content: space-between;
                align-items: center;
                color:rgba(var(--bs_timeline_box_color),0.7);
                & a{
                    text-decoration: none;
                    display: flex;
                    flex-wrap: nowrap;
                    width: 75%;
                    color:rgba(var(--bs_timeline_box_color),1);
                    & span{
                        color:rgba(var(--bs_timeline_box_color),0.7);
                    }
                    &:hover{
                        text-decoration: underline;
                    }
                }
                & strong{
                    color:rgba(var(--bs_timeline_box_color),1);
                    flex: 1.25;
                }
                & span{
                    flex: 0.75;
                }
                & strong,& span{
                    overflow: hidden;
                    text-overflow: ellipsis;
                    white-space: nowrap;
                    width: 100%;
                }
             }
             .bs_timeline_time{
                margin-left: auto;
                white-space: nowrap;
             }
             .bs_timeline_body{
                margin-top: 7px;
             }
             .bs_timeline_embed_repost{
                background: var(--bs_timeline_box_background);
                margin-top: 12px;
                border: 1px solid rgba(var(--bs_timeline_box_color),0.3);
                border-radius: 6px;
                padding:10px;
                transition: all 0.25s ease-out;
                &:hover{
                    background: rgba(var(--bs_timeline_box_bghover),0.16);
                }
                .bs_timeline_icon{
                    width: 16px;
                    height: 16px;
                    margin-right: 5px;
                    vertical-align: middle;
                    display: inline-block;
                }
                .bs_timeline_contents{
                    width:100%;
                }
                .bs_timeline_embed{
                    background: none;
                    &:hover{
                        background: none;
                    }
                }
             }
             .bs_timeline_embed{
                background: var(--bs_timeline_box_background);
                margin-top: 12px;
                border: 1px solid rgba(var(--bs_timeline_box_color),0.3);
                border-radius: 6px;
                transition: all 0.25s ease-out;
                &:hover{
                    background: rgba(var(--bs_timeline_box_bghover),0.16);
                }
                & a{
                    text-decoration: none;
                    color: rgba(var(--bs_timeline_box_color),1);
                }
                .bs_timeline_embed_thumb{
                    overflow: hidden;
                    & img{
                        border-top-left-radius: 5.5px;
                        border-top-right-radius: 5.5px;
                        width:100%;
                    }
                }
                .bs_timeline_embed_domain{
                    font-size:clac(var(--bs_timeline_box_font-size) - 2px);
                    padding:7px 10px 0;
                    color: rgba(var(--bs_timeline_box_color),0.7);
                }
                .bs_timeline_embed_title{
                    padding:2px 10px 0;
                    font-weight:bold;
                }
                .bs_timeline_embed_description{
                    padding:7px 10px;
                }

             }
             .bs_timeline_img{
                margin-top: 12px;
                display: flex;
                justify-content: center;
                align-items: center;
                gap:10px;
                &.multiple_2,&.multiple_4{
                    display: grid;
                    grid-template-columns: repeat(2, 1fr);
                    .bs_timeline_embed_thumb{
                        aspect-ratio: 1 / 1;
                        & img{
                            width:200%;
                        }
                    }
                }
                &.multiple_3{
                    display: grid;
                    grid-template:
                    "img1 img2"
                    "img1 img3";
                    grid-template-columns: 2.1fr 1fr;
                    .bs_timeline_embed_thumb{
                        &.multiple_1{
                            grid-area:img1;
                            aspect-ratio: 1 / 1;
                            & img{
                                width:200%;
                            }
                        }
                        & img{
                            width:150%;
                        }
                    }
                }
                .bs_timeline_embed_thumb{
                    border-radius: 6px;
                    display: flex;
                    justify-content: center;
                    align-items: center;
                    overflow: hidden;
                    & img{
                        border-radius: 5.5px;
                        width:100%;
                        object-fit: cover;
                    }
                }

             }
             .bs_timeline_footer{
                font-size:clac(var(--bs_timeline_box_font-size) - 2px);
                color: rgba(var(--bs_timeline_box_color),0.7);
                margin-top: 15px;
                display: flex;
                justify-content: space-between;
                & div{
                    width:33%;
                    display: flex;
                    align-items: center;
                    gap: 4px;
                }
             }
        }
    }
    @container (max-width:394px) {
        #bs_timeline_box{
            & section{
                .bs_timeline_title{
                    & a{
                        flex-wrap: wrap;
                        flex-direction: column;
                    }
                }
                .bs_timeline_body,.bs_timeline_footer{
                    margin-left: -50px;
                }
                .bs_timeline_embed_repost{
                    .bs_timeline_body,.bs_timeline_footer{
                        margin-left: 0px;
                    }
                }
            }
        }
    }
</style>
</head>
<body>
<div id="bs_timeline_box">
<?php
$count = count($response['feed']);
for($i = 0; $i < $count; $i++){

$post = $response['feed'][$i]['post'];

$arr_uri = explode("/", $post['uri']);
$post_uri = end($arr_uri);

if(isset($post['embed']['external'])){
$embed_url = $post['embed']['external']['uri'];
$embed_host = parse_url($embed_url);
$embed_host = $embed_host['host'];
}

$creat_date = $post['record']['createdAt'];

if( get_locale() == 'ja' ) {
    $creat_date = date('n月j日',strtotime($creat_date));
}else{
    $creat_date = date('M j',strtotime($creat_date));
}

?>
    <section post_uri="https://bsky.app/profile/<?php echo $post['author']['handle'].'/post/'.$post_uri; ?>">
    <?php if(isset($response['feed'][$i]['reason'])){ ?>
        <div class="bs_timeline_author_repost">
            <a href="https://bsky.app/profile/<?php echo $response['feed'][$i]['reason']['by']['handle']; ?>" target="_blank" rel="noopener noreferrer nofollow" role="link"><svg viewBox="0 0 576 512" height="16" width="16" tabindex="-1" style="margin-right: 4px; min-width: 16px;"><path fill="hsl(211, 20%, 70%)" d="M272 416c17.7 0 32-14.3 32-32s-14.3-32-32-32H160c-17.7 0-32-14.3-32-32V192h32c12.9 0 24.6-7.8 29.6-19.8s2.2-25.7-6.9-34.9l-64-64c-12.5-12.5-32.8-12.5-45.3 0l-64 64c-9.2 9.2-11.9 22.9-6.9 34.9s16.6 19.8 29.6 19.8l32 0 0 128c0 53 43 96 96 96H272zM304 96c-17.7 0-32 14.3-32 32s14.3 32 32 32l112 0c17.7 0 32 14.3 32 32l0 128H416c-12.9 0-24.6 7.8-29.6 19.8s-2.2 25.7 6.9 34.9l64 64c12.5 12.5 32.8 12.5 45.3 0l64-64c9.2-9.2 11.9-22.9 6.9-34.9s-16.6-19.8-29.6-19.8l-32 0V192c0-53-43-96-96-96L304 96z"></path></svg><?php _e('Repost by ',$DOMAIN);/* */ ?><?php echo $response['feed'][$i]['reason']['by']['displayName']; ?></a><?php _e(' ',$DOMAIN);/*によるリポスト*/ ?>
        </div>
    <?php } ?>
        <div class="bs_timeline_icon"><a href="https://bsky.app/profile/<?php echo $post['author']['handle']; ?>" target="_blank" rel="noopener noreferrer nofollow" role="link"><img src="<?php echo $post['author']['avatar']; ?>" width="40" height="40" alt="<?php echo $post['author']['displayName']; ?><?php _e('\'s icon',$DOMAIN);/* アイコン*/ ?>" loading="lazy"></a></div>
        <div class="bs_timeline_contents">
            <div class="bs_timeline_title">
                <a href="https://bsky.app/profile/<?php echo $post['author']['handle']; ?>" target="_blank" rel="noopener noreferrer nofollow" role="link">
                    <strong><?php echo $post['author']['displayName']; ?></strong>
                    <span>@<?php echo $post['author']['handle']; ?></span>
                </a>
                <div class="bs_timeline_time"><?php echo $creat_date; ?></div>
            </div>
            <div class="bs_timeline_body">
                <?php echo nl2br($post['record']['text']); ?>
                <?php
                //Embedがある場合
                if(isset($post['embed'])){
                    //リポストの場合
                    if(isset($post['embed']['record'])){ ?>
                <div class="bs_timeline_embed_repost" post_uri="https://bsky.app/profile/<?php
                    $re_arr_uri = explode("/", $post['embed']['record']['uri']);
                    $re_post_uri = end($re_arr_uri);
                    echo $post['embed']['record']['author']['handle'].'/post/'.$re_post_uri; ?>">
                    <div class="bs_timeline_contents">
                        <div class="bs_timeline_title">
                            <div class="bs_timeline_icon"><img src="<?php echo $post['embed']['record']['author']['avatar']; ?>" width="16" height="16" loading="lazy" alt="<?php echo $post['embed']['record']['author']['displayName']; ?><?php _e('\'s icon',$DOMAIN);/* アイコン*/ ?>"></div>
                            <strong><?php echo $post['embed']['record']['author']['displayName']; ?></strong>
                            <span>@<?php echo $post['embed']['record']['author']['handle']; ?></span>
                            <div class="bs_timeline_time"><?php
                                $index_date = $post['embed']['record']['indexedAt'];

                                if( get_locale() == 'ja' ) {
                                    $index_date = date('n月j日',strtotime($index_date));
                                }else{
                                    $index_date = date('M j',strtotime($index_date));
                                }
                                
                                echo $index_date; ?></div>
                        </div>
                        <div class="bs_timeline_body">
                            <?php echo nl2br($post['embed']['record']['value']['text']); ?>

                            <?php
                            if(isset($post['embed']['record']['embeds'])){
                                if(isset($post['embed']['record']['embeds'][0]['images'])){
                                //画像投稿の場合
                                $re_img_count = count($post['embed']['record']['embeds'][0]['images']);
                                $re_multiple = "";
                                if($re_img_count != 0){$re_multiple = " multiple_".$re_img_count;}
                            ?>
                            <div class="bs_timeline_img<?php echo $re_multiple; ?>">
                            <?php
                                for($zi = 0; $zi < $re_img_count; $zi++){
                            ?>
                                <div class="bs_timeline_embed_thumb<?php echo " multiple_".($zi+1); ?>"><img src="<?php echo $post['embed']['record']['embeds'][0]['images'][$zi]['thumb']; ?>" alt="<?php echo $post['embed']['record']['embeds'][0]['images'][$zi]['alt']; ?>" loading="lazy"></div>
                            <?php } ?>
                            </div>
                            <?php }elseif(isset($post['embed']['record']['embeds'][0]['external'])){ ?>

                            <div class="bs_timeline_embed">
                                <div class="bs_timeline_embed_thumb"><img src="<?php echo $post['embed']['record']['embeds'][0]['external']['thumb']; ?>" alt="<?php _e('thumbnail image',$DOMAIN);/*サムネイル画像*/ ?>" loading="lazy"></div>
                                <div class="bs_timeline_embed_domain"><?php 
                                    $re_embed_url = $post['embed']['record']['embeds'][0]['external']['uri'];
                                    $re_embed_host = parse_url($re_embed_url);
                                    $re_embed_host = $re_embed_host['host'];
                                    echo $re_embed_host; ?></div>
                                <div class="bs_timeline_embed_title"><?php echo $post['embed']['record']['embeds'][0]['external']['title']; ?></div>
                                <div class="bs_timeline_embed_description"><?php echo $post['embed']['record']['embeds'][0]['external']['description']; ?></div>
                            </div>

                            <?php }
                            } ?>
                        </div>
                    </div>
                <?php
                    //URL Embedの場合
                    }elseif(isset($post['embed']['external'])){

                ?>
                <div class="bs_timeline_embed">
                    <a href="<?php echo $embed_url; ?>" target="_blank" role="link">
                        <div class="bs_timeline_embed_thumb"><img src="<?php echo $post['embed']['external']['thumb']; ?>" alt="<?php _e('thumbnail image',$DOMAIN);/*サムネイル画像*/ ?>" loading="lazy"></div>
                        <div class="bs_timeline_embed_domain"><?php echo $embed_host; ?></div>
                        <div class="bs_timeline_embed_title"><?php echo $post['embed']['external']['title']; ?></div>
                        <div class="bs_timeline_embed_description"><?php echo $post['embed']['external']['description']; ?></div>
                    </a>
                <?php }else{
                    //画像投稿の場合
                    $img_count = count($post['embed']['images']);
                    $multiple = "";
                    if($img_count != 0){$multiple = " multiple_".$img_count;}
                ?>
                    <div class="bs_timeline_img<?php echo $multiple; ?>">
                <?php
                    for($z = 0; $z < $img_count; $z++){
                ?>
                        <div class="bs_timeline_embed_thumb<?php echo " multiple_".($z+1); ?>"><img src="<?php echo $post['embed']['images'][$z]['thumb']; ?>" alt="<?php echo $post['embed']['images'][$z]['alt']; ?>" loading="lazy"></div>
                <?php }
                } ?>
                </div>
                <?php } ?>
            </div>
            <div class="bs_timeline_footer">
                <div class="bs_timeline_reply">
                    <svg fill="none" viewBox="0 0 24 24" stroke-width="3" stroke="currentColor" width="15" height="15" style="color: rgb(102, 127, 153);"><path stroke-linecap="round" stroke-linejoin="round" d="M2.25 12.76c0 1.6 1.123 2.994 2.707 3.227 1.068.157 2.148.279 3.238.364.466.037.893.281 1.153.671L12 21l2.652-3.978c.26-.39.687-.634 1.153-.67 1.09-.086 2.17-.208 3.238-.365 1.584-.233 2.707-1.626 2.707-3.228V6.741c0-1.602-1.123-2.995-2.707-3.228A48.394 48.394 0 0012 3c-2.392 0-4.744.175-7.043.513C3.373 3.746 2.25 5.14 2.25 6.741v6.018z"></path></svg>
                    <?php if($post['replyCount'] > 0){echo $post['replyCount'];} ?>
                </div>
                <div class="bs_timeline_repost">
                    <svg viewBox="0 0 24 24" width="20" height="20" style="color: rgb(102, 127, 153);"><path stroke="currentColor" stroke-width="2.2" stroke-linejoin="round" fill="none" d="M 14.437 18.081 L 5.475 18.095 C 4.7 18.095 4.072 17.467 4.072 16.692 L 4.082 6.65 L 1.22 10.854 M 4.082 6.65 L 7.006 10.854 M 9.859 6.65 L 18.625 6.654 C 19.4 6.654 20.028 7.282 20.028 8.057 L 20.031 18.081 L 17.167 13.646 M 20.031 18.081 L 22.866 13.646"></path></svg>
                    <?php if($post['repostCount'] > 0){echo $post['repostCount'];} ?>
                </div>
                <div class="bs_timeline_like">
                    <svg viewBox="0 0 24 24" width="16" height="16" style="color: rgb(102, 127, 153);"><path stroke-width="3" stroke="currentColor" fill="none" d="M 3.859 13.537 L 10.918 20.127 C 11.211 20.4 11.598 20.552 12 20.552 C 12.402 20.552 12.789 20.4 13.082 20.127 L 20.141 13.537 C 21.328 12.431 22 10.88 22 9.259 L 22 9.033 C 22 6.302 20.027 3.974 17.336 3.525 C 15.555 3.228 13.742 3.81 12.469 5.084 L 12 5.552 L 11.531 5.084 C 10.258 3.81 8.445 3.228 6.664 3.525 C 3.973 3.974 2 6.302 2 9.033 L 2 9.259 C 2 10.88 2.672 12.431 3.859 13.537 Z"></path></svg>
                    <?php if($post['likeCount'] > 0){echo $post['likeCount'];} ?>
                </div>
            </div>
        </div>
    </section>
<?php } ?>
</div>

<script>
var bs_section = document.querySelectorAll("#bs_timeline_box section,.bs_timeline_embed_repost");
for(i in bs_section){
    if (bs_section.hasOwnProperty(i)) {
        bs_section[i].addEventListener("click", () => {
            var post_uri = event.currentTarget.getAttribute("post_uri");
            window.open(post_uri, "_blank");
        });
    }
}

var a_tags = document.querySelectorAll("#bs_timeline_box a,.bs_timeline_embed_repost");
for(i in a_tags){
    if (a_tags.hasOwnProperty(i)) {
        a_tags[i].addEventListener("click", () => {
            event.stopPropagation();
        });
    }
}
</script>
<!-- BlueskyTimeline <?php echo $VERSION; ?> -->
</body>
</html>

<?php
            $data = ob_get_contents();
            ob_end_clean();
            return $data;
        }

        $timeline_html = makeHtml($background, $color, $response, $gtm, $DOMAIN, $VERSION);

        //10分間のキャッシュをセット
        set_transient( 'cache-rotation', 1, MINUTE_IN_SECONDS * 10 );
        //30日のキャッシュをセット
        set_transient( 'integrity-time', $response['feed'][0]['post']['record']['createdAt'], DAY_IN_SECONDS * 30 );
        //30日のキャッシュをセット
        set_transient( 'timeline-cache', $timeline_html, DAY_IN_SECONDS * 30 );

        //HTMLキャッシュが存在していないもしくは 管理画面からのアップデートの時
        if( empty($cache) || !empty($update_flg) ){
            //出力
            echo $timeline_html;
        }

    }
}else{ ?>

<!DOCTYPE html>
<html lang="<?php _e('en',$DOMAIN);/*ja*/ ?>">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="robots" content="noindex,nofollow">
    <title>BlueskyTimeline</title>
</head>
<body>
<!-- Plugin is not active. -->
<!-- BlueskyTimeline <?php echo $VERSION; ?> -->
</body>
</html>

<?php }

?>